@@ -139,6 +139,7 @@ class Options:  # pylint: disable=too-many-instance-attributes
     list_rules: bool = False
     list_tags: bool = False
     write_list: list[str] = field(default_factory=list)
+    write_exclude_list: list[str] = field(default_factory=list)
     parseable: bool = False
     quiet: bool = False
     rulesdirs: list[Path] = field(default_factory=list)
@@ -176,7 +177,7 @@ class Options:  # pylint: disable=too-many-instance-attributes
     max_tasks: int = 100
     max_block_depth: int = 20
     # Refer to https://docs.ansible.com/ansible/latest/reference_appendices/release_and_maintenance.html#ansible-core-support-matrix
-    _default_supported = ["2.15.", "2.16.", "2.17."]
+    _default_supported = ["2.15.", "2.16.", "2.17.", "2.18."]
     supported_ansible_also: list[str] = field(default_factory=list)
 
     @property
