@@ -26,11 +26,12 @@ from ansiblelint.utils import load_plugin
 from ansiblelint.yaml_utils import clean_json
 
 if TYPE_CHECKING:
+    from ansible.plugins.loader import PluginLoadContext
+
     from ansiblelint.errors import MatchError
     from ansiblelint.file_utils import Lintable
     from ansiblelint.utils import Task
 
-
 _logger = logging.getLogger(__name__)
 
 ignored_re = re.compile(
@@ -70,11 +71,12 @@ class ValidationPassedError(Exception):
     """Exception to be raised when validation passes."""
 
 
-class CustomAnsibleModule(basic.AnsibleModule):  # type: ignore[misc]
+class CustomAnsibleModule(basic.AnsibleModule):  # type: ignore[misc,no-any-unimported]
     """Mock AnsibleModule class."""
 
-    def __init__(self, *args: str, **kwargs: str) -> None:
+    def __init__(self, *args: Any, **kwargs: Any) -> None:
         """Initialize AnsibleModule mock."""
+        kwargs["no_log"] = True
         super().__init__(*args, **kwargs)
         raise ValidationPassedError
 
@@ -86,7 +88,7 @@ class ArgsRule(AnsibleLintRule):
     severity = "HIGH"
     description = "Check whether tasks are using correct module options."
     tags = ["syntax", "experimental"]
-    version_added = "v6.10.0"
+    version_changed = "6.10.0"
     module_aliases: dict[str, str] = {"block/always/rescue": "block/always/rescue"}
     _ids = {
         "args[module]": description,
@@ -105,7 +107,7 @@ class ArgsRule(AnsibleLintRule):
         if module_name in self.module_aliases:
             return []
 
-        loaded_module = load_plugin(module_name)
+        loaded_module: PluginLoadContext = load_plugin(module_name)  # type: ignore[no-any-unimported]
 
         # https://github.com/ansible/ansible-lint/issues/3200
         # since "ps1" modules cannot be executed on POSIX platforms, we will
@@ -135,14 +137,21 @@ class ArgsRule(AnsibleLintRule):
             module_args.update(workarounds_inject_map[loaded_module.resolved_fqcn])
         if loaded_module.resolved_fqcn in workarounds_drop_map:
             for key in workarounds_drop_map[loaded_module.resolved_fqcn]:
-                if key in module_args:
-                    del module_args[key]
+                module_args.pop(key, None)
 
         with mock.patch.object(
             mock_ansible_module,
             "AnsibleModule",
             CustomAnsibleModule,
         ):
+            if not loaded_module.plugin_resolved_name:
+                _logger.warning(
+                    "Unable to load module %s at %s:%s for options validation",
+                    module_name,
+                    file.filename if file else None,
+                    task[LINE_NUMBER_KEY],
+                )
+                return []
             spec = importlib.util.spec_from_file_location(
                 name=loaded_module.plugin_resolved_name,
                 location=loaded_module.plugin_resolved_path,
@@ -271,7 +280,7 @@ class ArgsRule(AnsibleLintRule):
 
 # testing code to be loaded only with pytest or when executed the rule file
 if "pytest" in sys.modules:
-    import pytest  # noqa: TCH002
+    import pytest  # noqa: TC002
 
     from ansiblelint.runner import Runner  # pylint: disable=ungrouped-imports
 
