@@ -20,9 +20,11 @@
 # spell-checker:ignore dwim
 # pylint: disable=too-many-lines
 """Generic utility helpers."""
+
 from __future__ import annotations
 
 import ast
+import collections.abc
 import contextlib
 import inspect
 import logging
@@ -37,11 +39,13 @@ from typing import TYPE_CHECKING, Any
 import ruamel.yaml.parser
 import yaml
 from ansible.errors import AnsibleError, AnsibleParserError
+from ansible.module_utils._text import to_bytes
 from ansible.module_utils.parsing.convert_bool import boolean
 from ansible.parsing.dataloader import DataLoader
 from ansible.parsing.mod_args import ModuleArgsParser
 from ansible.parsing.plugin_docs import read_docstring
 from ansible.parsing.splitter import split_args
+from ansible.parsing.vault import PromptVaultSecret
 from ansible.parsing.yaml.constructor import AnsibleConstructor, AnsibleMapping
 from ansible.parsing.yaml.loader import AnsibleLoader
 from ansible.parsing.yaml.objects import AnsibleBaseYAMLObject, AnsibleSequence
@@ -54,7 +58,9 @@ from ansible.plugins.loader import (
 from ansible.template import Templar
 from ansible.utils.collection_loader import AnsibleCollectionConfig
 from yaml.composer import Composer
+from yaml.parser import ParserError
 from yaml.representer import RepresenterError
+from yaml.scanner import ScannerError
 
 from ansiblelint._internal.rules import (
     AnsibleParserErrorRule,
@@ -68,7 +74,6 @@ from ansiblelint.constants import (
     INCLUSION_ACTION_NAMES,
     LINE_NUMBER_KEY,
     NESTED_TASK_KEYS,
-    PLAYBOOK_TASK_KEYWORDS,
     ROLE_IMPORT_ACTION_NAMES,
     SKIPPED_RULES_KEY,
     FileType,
@@ -84,7 +89,6 @@ if TYPE_CHECKING:
 # string as the password to enable such yaml files to be opened and parsed
 # successfully.
 DEFAULT_VAULT_PASSWORD = "x"  # noqa: S105
-COLLECTION_PLAY_RE = re.compile(r"^[\w\d_]+\.[\w\d_]+\.[\w\d_]+$")
 
 PLAYBOOK_DIR = os.environ.get("ANSIBLE_PLAYBOOK_DIR", None)
 
@@ -92,11 +96,14 @@ PLAYBOOK_DIR = os.environ.get("ANSIBLE_PLAYBOOK_DIR", None)
 _logger = logging.getLogger(__name__)
 
 
-def parse_yaml_from_file(filepath: str) -> AnsibleBaseYAMLObject:
+def parse_yaml_from_file(filepath: str) -> AnsibleBaseYAMLObject:  # type: ignore[no-any-unimported]
     """Extract a decrypted YAML object from file."""
     dataloader = DataLoader()
-    if hasattr(dataloader, "set_vault_password"):
-        dataloader.set_vault_password(DEFAULT_VAULT_PASSWORD)
+    if hasattr(dataloader, "set_vault_secrets"):
+        dataloader.set_vault_secrets(
+            [("default", PromptVaultSecret(_bytes=to_bytes(DEFAULT_VAULT_PASSWORD)))]
+        )
+
     return dataloader.load_from_file(filepath)
 
 
@@ -107,7 +114,7 @@ def path_dwim(basedir: str, given: str) -> str:
     return str(dataloader.path_dwim(given))
 
 
-def ansible_templar(basedir: Path, templatevars: Any) -> Templar:
+def ansible_templar(basedir: Path, templatevars: Any) -> Templar:  # type: ignore[no-any-unimported]
     """Create an Ansible Templar using templatevars."""
     # `basedir` is the directory containing the lintable file.
     # Therefore, for tasks in a role, `basedir` has the form
@@ -118,7 +125,7 @@ def ansible_templar(basedir: Path, templatevars: Any) -> Templar:
         basedir = basedir.parent
 
     dataloader = DataLoader()
-    dataloader.set_basedir(basedir)
+    dataloader.set_basedir(str(basedir))
     templar = Templar(dataloader, variables=templatevars)
     return templar
 
@@ -237,7 +244,7 @@ def tokenize(value: str) -> tuple[list[str], dict[str, str]]:
     return (args, kwargs)
 
 
-def playbook_items(pb_data: AnsibleBaseYAMLObject) -> ItemsView:  # type: ignore[type-arg]
+def playbook_items(pb_data: AnsibleBaseYAMLObject) -> ItemsView:  # type: ignore[type-arg,no-any-unimported]
     """Return a list of items from within the playbook."""
     if isinstance(pb_data, dict):
         return pb_data.items()
@@ -254,7 +261,11 @@ def set_collections_basedir(basedir: Path) -> None:
     """Set the playbook directory as playbook_paths for the collection loader."""
     # Ansible expects only absolute paths inside `playbook_paths` and will
     # produce weird errors if we use a relative one.
-    AnsibleCollectionConfig.playbook_paths = str(basedir.resolve())
+    # https://github.com/psf/black/issues/4519
+    # fmt: off
+    AnsibleCollectionConfig.playbook_paths = (  # pyright: ignore[reportAttributeAccessIssue]
+        str(basedir.resolve()))
+    # fmt: on
 
 
 def template(
@@ -290,7 +301,7 @@ class HandleChildren:
     rules: RulesCollection = field(init=True, repr=False)
     app: App
 
-    def include_children(  # pylint: disable=too-many-return-statements
+    def include_children(
         self,
         lintable: Lintable,
         k: str,
@@ -299,30 +310,13 @@ class HandleChildren:
     ) -> list[Lintable]:
         """Include children."""
         basedir = str(lintable.path.parent)
-        # import_playbook only accepts a string as argument (no dict syntax)
-        if k in (
-            "import_playbook",
-            "ansible.builtin.import_playbook",
-        ) and not isinstance(v, str):
-            return []
 
         # handle special case include_tasks: name=filename.yml
         if k in INCLUSION_ACTION_NAMES and isinstance(v, dict) and "file" in v:
             v = v["file"]
 
         # we cannot really parse any jinja2 in includes, so we ignore them
-        if not v or "{{" in v:
-            return []
-
-        if k in ("import_playbook", "ansible.builtin.import_playbook"):
-            included = Path(basedir) / v
-            if not included.exists():
-                msg = f"Failed to find {v} playbook."
-            elif not self.app.runtime.has_playbook(v, basedir=Path(basedir)):
-                msg = f"Failed to load {v} playbook due to failing syntax check."
-            else:
-                return [Lintable(included, kind=parent_type)]
-            logging.error(msg)
+        if not v or not isinstance(v, str) or "{{" in v:
             return []
 
         # handle include: filename.yml tags=blah
@@ -348,7 +342,7 @@ class HandleChildren:
         self,
         lintable: Lintable,
         k: str,
-        v: None | Any,
+        v: Any | None,
         parent_type: FileType,
     ) -> list[Lintable]:
         """TasksHandlers Children."""
@@ -358,6 +352,7 @@ class HandleChildren:
             raise MatchError(
                 message="A malformed block was encountered while loading a block.",
                 rule=RuntimeErrorRule(),
+                lintable=lintable,
             )
         for task_handler in v:
             # ignore empty tasks, `-`
@@ -408,23 +403,21 @@ class HandleChildren:
         """Verify that the task handler action is valid for role include."""
         module = th_action["__ansible_module__"]
 
+        lintable = Lintable(
+            self.rules.options.lintables[0] if self.rules.options.lintables else ".",
+        )
         if "name" not in th_action:
             raise MatchError(
                 message=f"Failed to find required 'name' key in {module!s}",
                 rule=self.rules.rules[0],
-                lintable=Lintable(
-                    (
-                        self.rules.options.lintables[0]
-                        if self.rules.options.lintables
-                        else "."
-                    ),
-                ),
+                lintable=lintable,
             )
 
         if not isinstance(th_action["name"], str):
             raise MatchError(
                 message=f"Value assigned to 'name' key on '{module!s}' is not a string.",
                 rule=self.rules.rules[1],
+                lintable=lintable,
             )
 
     def roles_children(
@@ -446,7 +439,7 @@ class HandleChildren:
                 if "role" in role or "name" in role:
                     if "tags" not in role or "skip_ansible_lint" not in role["tags"]:
                         results.extend(
-                            _look_for_role_files(
+                            self._look_for_role_files(
                                 basedir,
                                 role.get("role", role.get("name")),
                             ),
@@ -455,9 +448,134 @@ class HandleChildren:
                     msg = f'role dict {role} does not contain a "role" or "name" key'
                     raise SystemExit(msg)
             else:
-                results.extend(_look_for_role_files(basedir, role))
+                results.extend(self._look_for_role_files(basedir, role))
         return results
 
+    def import_playbook_children(
+        self,
+        lintable: Lintable,
+        k: str,  # pylint: disable=unused-argument
+        v: Any,
+        parent_type: FileType,
+    ) -> list[Lintable]:
+        """Include import_playbook children."""
+
+        def append_playbook_path(loc: str, playbook_path: list[str]) -> None:
+            possible_paths.append(
+                Path(
+                    path_dwim(
+                        os.path.expanduser(loc),
+                        os.path.join(
+                            "ansible_collections",
+                            namespace_name,
+                            collection_name,
+                            "playbooks",
+                            *playbook_path,
+                        ),
+                    ),
+                ),
+            )
+
+        # import_playbook only accepts a string as argument (no dict syntax)
+        if not isinstance(v, str):
+            return []
+
+        possible_paths = []
+        namespace_name, collection_name, *playbook_path = parse_fqcn(v)
+        if namespace_name and collection_name:
+            for loc in self.app.runtime.config.collections_paths:
+                append_playbook_path(
+                    loc,
+                    playbook_path[:-1] + [f"{playbook_path[-1]}.yml"],
+                )
+                append_playbook_path(
+                    loc,
+                    playbook_path[:-1] + [f"{playbook_path[-1]}.yaml"],
+                )
+        else:
+            possible_paths.append(lintable.path.parent / v)
+
+        for possible_path in possible_paths:
+            if not possible_path.exists():
+                msg = f"Failed to find {v} playbook."
+            elif not self.app.runtime.has_playbook(
+                str(possible_path),
+            ):
+                msg = f"Failed to load {v} playbook due to failing syntax check."
+                break
+            elif namespace_name and collection_name:
+                # don't lint foreign playbook
+                return []
+            else:
+                return [Lintable(possible_path, kind=parent_type)]
+
+        _logger.error(msg)
+        return []
+
+    def _look_for_role_files(self, basedir: str, role: str) -> list[Lintable]:
+        role_path = self._rolepath(basedir, role)
+        if not role_path:  # pragma: no branch
+            return []
+
+        results = []
+
+        for kind in ["tasks", "meta", "handlers", "vars", "defaults"]:
+            current_path = os.path.join(role_path, kind)
+            for folder, _, files in os.walk(current_path):
+                for file in files:
+                    file_ignorecase = file.lower()
+                    if file_ignorecase.endswith((".yml", ".yaml")):
+                        results.append(Lintable(os.path.join(folder, file)))
+
+        return results
+
+    def _rolepath(self, basedir: str, role: str) -> str | None:
+        role_path = None
+        namespace_name, collection_name, role_name = parse_fqcn(role)
+
+        possible_paths = [
+            # if included from a playbook
+            path_dwim(basedir, os.path.join("roles", role_name)),
+            path_dwim(basedir, role_name),
+            # if included from roles/[role]/meta/main.yml
+            path_dwim(basedir, os.path.join("..", "..", "..", "roles", role_name)),
+            path_dwim(basedir, os.path.join("..", "..", role_name)),
+            # if checking a role in the current directory
+            path_dwim(basedir, os.path.join("..", role_name)),
+        ]
+
+        for loc in self.app.runtime.config.default_roles_path:
+            loc = os.path.expanduser(loc)
+            possible_paths.append(path_dwim(loc, role_name))
+
+        if namespace_name and collection_name:
+            for loc in get_app(cached=True).runtime.config.collections_paths:
+                loc = os.path.expanduser(loc)
+                possible_paths.append(
+                    path_dwim(
+                        loc,
+                        os.path.join(
+                            "ansible_collections",
+                            namespace_name,
+                            collection_name,
+                            "roles",
+                            role_name,
+                        ),
+                    ),
+                )
+
+        possible_paths.append(path_dwim(basedir, ""))
+
+        for path_option in possible_paths:  # pragma: no branch
+            if os.path.isdir(path_option):
+                role_path = path_option
+                break
+
+        if role_path:  # pragma: no branch
+            add_all_plugin_dirs(role_path)
+
+        return role_path
+
 
 def _get_task_handler_children_for_tasks_or_playbooks(
     task_handler: dict[str, Any],
@@ -504,74 +622,6 @@ def _get_task_handler_children_for_tasks_or_playbooks(
     raise LookupError(msg)
 
 
-def _rolepath(basedir: str, role: str) -> str | None:
-    role_path = None
-    namespace_name, collection_name, role_name = (
-        role.split(".") if is_fqcn(role) else ("", "", role)
-    )
-
-    possible_paths = [
-        # if included from a playbook
-        path_dwim(basedir, os.path.join("roles", role_name)),
-        path_dwim(basedir, role_name),
-        # if included from roles/[role]/meta/main.yml
-        path_dwim(basedir, os.path.join("..", "..", "..", "roles", role_name)),
-        path_dwim(basedir, os.path.join("..", "..", role_name)),
-        # if checking a role in the current directory
-        path_dwim(basedir, os.path.join("..", role_name)),
-    ]
-
-    for loc in get_app(cached=True).runtime.config.default_roles_path:
-        loc = os.path.expanduser(loc)
-        possible_paths.append(path_dwim(loc, role_name))
-
-    if namespace_name and collection_name:
-        for loc in get_app(cached=True).runtime.config.collections_paths:
-            loc = os.path.expanduser(loc)
-            possible_paths.append(
-                path_dwim(
-                    loc,
-                    os.path.join(
-                        "ansible_collections",
-                        namespace_name,
-                        collection_name,
-                        "roles",
-                        role_name,
-                    ),
-                ),
-            )
-
-    possible_paths.append(path_dwim(basedir, ""))
-
-    for path_option in possible_paths:  # pragma: no branch
-        if os.path.isdir(path_option):
-            role_path = path_option
-            break
-
-    if role_path:  # pragma: no branch
-        add_all_plugin_dirs(role_path)
-
-    return role_path
-
-
-def _look_for_role_files(basedir: str, role: str) -> list[Lintable]:
-    role_path = _rolepath(basedir, role)
-    if not role_path:  # pragma: no branch
-        return []
-
-    results = []
-
-    for kind in ["tasks", "meta", "handlers", "vars", "defaults"]:
-        current_path = os.path.join(role_path, kind)
-        for folder, _, files in os.walk(current_path):
-            for file in files:
-                file_ignorecase = file.lower()
-                if file_ignorecase.endswith((".yml", ".yaml")):
-                    results.append(Lintable(os.path.join(folder, file)))
-
-    return results
-
-
 def _sanitize_task(task: dict[str, Any]) -> dict[str, Any]:
     """Return a stripped-off task structure compatible with new Ansible.
 
@@ -683,17 +733,18 @@ def task_to_str(task: dict[str, Any]) -> str:
         ]
     ]
 
-    _raw_params = action.get("_raw_params", [])
-    if isinstance(_raw_params, list):
-        for item in _raw_params:
+    raw_params = action.get("_raw_params", [])
+    if isinstance(raw_params, list):
+        for item in raw_params:
             args.extend(str(item))
     else:
-        args.append(_raw_params)
+        args.append(raw_params)
 
     return f"{action['__ansible_module__']} {' '.join(args)}"
 
 
-def extract_from_list(
+# pylint: disable=too-many-nested-blocks
+def extract_from_list(  # type: ignore[no-any-unimported]
     blocks: AnsibleBaseYAMLObject,
     candidates: list[str],
     *,
@@ -701,23 +752,24 @@ def extract_from_list(
 ) -> list[Any]:
     """Get action tasks from block structures."""
     results = []
-    for block in blocks:
-        for candidate in candidates:
-            if isinstance(block, dict) and candidate in block:
-                if isinstance(block[candidate], list):
-                    subresults = add_action_type(block[candidate], candidate)
-                    if recursive:
-                        subresults.extend(
-                            extract_from_list(
-                                subresults,
-                                candidates,
-                                recursive=recursive,
-                            ),
-                        )
-                    results.extend(subresults)
-                elif block[candidate] is not None:
-                    msg = f"Key '{candidate}' defined, but bad value: '{block[candidate]!s}'"
-                    raise RuntimeError(msg)
+    if isinstance(blocks, Iterable):
+        for block in blocks:
+            for candidate in candidates:
+                if isinstance(block, dict) and candidate in block:
+                    if isinstance(block[candidate], list):
+                        subresults = add_action_type(block[candidate], candidate)
+                        if recursive:
+                            subresults.extend(
+                                extract_from_list(
+                                    subresults,
+                                    candidates,
+                                    recursive=recursive,
+                                ),
+                            )
+                        results.extend(subresults)
+                    elif block[candidate] is not None:
+                        msg = f"Key '{candidate}' defined, but bad value: '{block[candidate]!s}'"
+                        raise RuntimeError(msg)
     return results
 
 
@@ -821,7 +873,7 @@ class Task(dict[str, Any]):
             if file_name:
                 paths = file_name.split("/")
                 is_handler_file = "handlers" in paths
-        return is_handler_file if is_handler_file else ".handlers[" in self.position
+        return is_handler_file or ".handlers[" in self.position
 
     def __repr__(self) -> str:
         """Return a string representation of the task."""
@@ -839,8 +891,33 @@ class Task(dict[str, Any]):
         """Provide support for 'key in task'."""
         yield from (f for f in self.normalized_task)
 
+    def get_error_line(self, path: list[str | int]) -> int:
+        """Return error line number."""
+        ctx = self.normalized_task
+        line = self.normalized_task[LINE_NUMBER_KEY]
+        for _ in path:
+            if (
+                isinstance(ctx, collections.abc.Container) and _ in ctx
+            ):  # isinstance(ctx, collections.abc.Container) and
+                value = ctx.get(  # pyright: ignore[reportAttributeAccessIssue]
+                    _  # pyright: ignore[reportArgumentType]
+                )
+                if isinstance(value, dict):
+                    ctx = value
+                if (
+                    isinstance(ctx, collections.abc.Container)
+                    and LINE_NUMBER_KEY in ctx
+                ):
+                    line = ctx[LINE_NUMBER_KEY]  # pyright: ignore[reportIndexIssue]
+                # else:
+                #     break
+        if not isinstance(line, int):
+            msg = "Line number is not an integer"
+            raise TypeError(msg)
+        return line
 
-def task_in_list(
+
+def task_in_list(  # type: ignore[no-any-unimported]
     data: AnsibleBaseYAMLObject,
     file: Lintable,
     kind: str,
@@ -848,24 +925,25 @@ def task_in_list(
 ) -> Iterator[Task]:
     """Get action tasks from block structures."""
 
-    def each_entry(data: AnsibleBaseYAMLObject, position: str) -> Iterator[Task]:
-        if not data:
+    def each_entry(data: AnsibleBaseYAMLObject, position: str) -> Iterator[Task]:  # type: ignore[no-any-unimported]
+
+        if not data or not isinstance(data, Iterable):
             return
         for entry_index, entry in enumerate(data):
             if not entry:
                 continue
-            _pos = f"{position}[{entry_index}]"
+            pos_ = f"{position}[{entry_index}]"
             if isinstance(entry, dict):
                 yield Task(
                     entry,
-                    position=_pos,
+                    position=pos_,
                 )
             for block in [k for k in entry if k in NESTED_TASK_KEYS]:
                 yield from task_in_list(
                     data=entry[block],
                     file=file,
                     kind="tasks",
-                    position=f"{_pos}.{block}",
+                    position=f"{pos_}.{block}",
                 )
 
     if not isinstance(data, list):
@@ -889,43 +967,35 @@ def task_in_list(
         yield from each_entry(data, position)
 
 
-def add_action_type(actions: AnsibleBaseYAMLObject, action_type: str) -> list[Any]:
+def add_action_type(  # type: ignore[no-any-unimported]
+    actions: AnsibleBaseYAMLObject, action_type: str
+) -> AnsibleSequence:
     """Add action markers to task objects."""
-    results = []
-    for action in actions:
-        # ignore empty task
-        if not action:
-            continue
-        action["__ansible_action_type__"] = BLOCK_NAME_TO_ACTION_TYPE_MAP[action_type]
-        results.append(action)
+    results = AnsibleSequence()
+    if isinstance(actions, Iterable):
+        for action in actions:
+            # ignore empty task
+            if not action:
+                continue
+            action["__ansible_action_type__"] = BLOCK_NAME_TO_ACTION_TYPE_MAP[
+                action_type
+            ]
+            results.append(action)
     return results
 
 
-def get_action_tasks(data: AnsibleBaseYAMLObject, file: Lintable) -> list[Any]:
-    """Get a flattened list of action tasks from the file."""
-    tasks = []
-    if file.kind in ["tasks", "handlers"]:
-        tasks = add_action_type(data, file.kind)
-    else:
-        tasks.extend(extract_from_list(data, PLAYBOOK_TASK_KEYWORDS))
-
-    # Add sub-elements of block/rescue/always to tasks list
-    tasks.extend(extract_from_list(tasks, NESTED_TASK_KEYS, recursive=True))
-
-    return tasks
-
-
 @cache
-def parse_yaml_linenumbers(
+def parse_yaml_linenumbers(  # type: ignore[no-any-unimported]
     lintable: Lintable,
-) -> AnsibleBaseYAMLObject:
+) -> AnsibleBaseYAMLObject | None:
     """Parse yaml as ansible.utils.parse_yaml but with linenumbers.
 
     The line numbers are stored in each node's LINE_NUMBER_KEY key.
     """
-    result = []
+    result = AnsibleSequence()
 
-    def compose_node(parent: yaml.nodes.Node, index: int) -> yaml.nodes.Node:
+    # signature of Composer.compose_node
+    def compose_node(parent: yaml.nodes.Node | None, index: int) -> yaml.nodes.Node:
         # the line number where the previous token has ended (plus empty lines)
         line = loader.line
         node = Composer.compose_node(loader, parent, index)
@@ -935,14 +1005,15 @@ def parse_yaml_linenumbers(
         node.__line__ = line + 1  # type: ignore[attr-defined]
         return node
 
-    def construct_mapping(
-        node: AnsibleBaseYAMLObject,
-        *,
-        deep: bool = False,
+    # signature of AnsibleConstructor.construct_mapping
+    def construct_mapping(  # type: ignore[no-any-unimported]
+        node: yaml.MappingNode,
+        deep: bool = False,  # noqa: FBT002
     ) -> AnsibleMapping:
+        # pyright: ignore[reportArgumentType]
         mapping = AnsibleConstructor.construct_mapping(loader, node, deep=deep)
-        if hasattr(node, "__line__"):
-            mapping[LINE_NUMBER_KEY] = node.__line__
+        if hasattr(node, LINE_NUMBER_KEY):
+            mapping[LINE_NUMBER_KEY] = getattr(node, LINE_NUMBER_KEY)
         else:
             mapping[LINE_NUMBER_KEY] = mapping._line_number  # noqa: SLF001
         mapping[FILENAME_KEY] = lintable.path
@@ -953,7 +1024,9 @@ def parse_yaml_linenumbers(
         if "vault_password" in inspect.getfullargspec(AnsibleLoader.__init__).args:
             kwargs["vault_password"] = DEFAULT_VAULT_PASSWORD
         loader = AnsibleLoader(lintable.content, **kwargs)
+        # redefine Composer.compose_node
         loader.compose_node = compose_node
+        # redefine AnsibleConstructor.construct_mapping
         loader.construct_mapping = construct_mapping
         # while Ansible only accepts single documents, we also need to load
         # multi-documents, as we attempt to load any YAML file, not only
@@ -964,8 +1037,8 @@ def parse_yaml_linenumbers(
                 break
             result.append(data)
     except (
-        yaml.parser.ParserError,
-        yaml.scanner.ScannerError,
+        ParserError,
+        ScannerError,
         yaml.constructor.ConstructorError,
         ruamel.yaml.parser.ParserError,
     ) as exc:
@@ -1115,7 +1188,7 @@ def parse_examples_from_plugin(lintable: Lintable) -> tuple[int, str]:
 
 
 @lru_cache
-def load_plugin(name: str) -> PluginLoadContext:
+def load_plugin(name: str) -> PluginLoadContext:  # type: ignore[no-any-unimported]
     """Return loaded ansible plugin/module."""
     loaded_module = action_loader.find_plugin_with_context(
         name,
@@ -1136,3 +1209,8 @@ def load_plugin(name: str) -> PluginLoadContext:
             check_aliases=True,
         )
     return loaded_module
+
+
+def parse_fqcn(name: str) -> tuple[str, ...]:
+    """Parse name parameter into FQCN segments."""
+    return tuple(name.split(".")) if is_fqcn(name) else ("", "", name)
