@@ -7,7 +7,6 @@ import functools
 import logging
 import os
 import re
-from collections.abc import Callable, Iterator, Sequence
 from io import StringIO
 from pathlib import Path
 from re import Pattern
@@ -23,7 +22,7 @@ from ruamel.yaml.emitter import Emitter, ScalarAnalysis
 # To make the type checkers happy, we import from ruamel.yaml.main instead.
 from ruamel.yaml.main import YAML
 from ruamel.yaml.parser import ParserError
-from ruamel.yaml.scalarint import ScalarInt
+from ruamel.yaml.scalarint import HexInt, ScalarInt
 from yamllint.config import YamlLintConfig
 
 from ansiblelint.constants import (
@@ -35,8 +34,9 @@ from ansiblelint.utils import Task
 
 if TYPE_CHECKING:
     # noinspection PyProtectedMember
+    from collections.abc import Callable, Iterator, Sequence
+
     from ruamel.yaml.comments import LineCol
-    from ruamel.yaml.compat import StreamTextType
     from ruamel.yaml.nodes import ScalarNode
     from ruamel.yaml.representer import RoundTripRepresenter
     from ruamel.yaml.tokens import CommentToken
@@ -46,28 +46,17 @@ if TYPE_CHECKING:
 _logger = logging.getLogger(__name__)
 
 
-YAMLLINT_CONFIG = """
-extends: default
-rules:
-  comments:
-    # https://github.com/prettier/prettier/issues/6780
-    min-spaces-from-content: 1
-  # https://github.com/adrienverge/yamllint/issues/384
-  comments-indentation: false
-  document-start: disable
-  # 160 chars was the default used by old E204 rule, but
-  # you can easily change it or disable in your .yamllint file.
-  line-length:
-    max: 160
-  # We are adding an extra space inside braces as that's how prettier does it
-  # and we are trying not to fight other linters.
-  braces:
-    min-spaces-inside: 0  # yamllint defaults to 0
-    max-spaces-inside: 1  # yamllint defaults to 0
-  octal-values:
-    forbid-implicit-octal: true  # yamllint defaults to false
-    forbid-explicit-octal: true  # yamllint defaults to false
-"""
+class CustomYamlLintConfig(YamlLintConfig):  # type: ignore[misc,no-any-unimported]
+    """Extension of YamlLintConfig."""
+
+    def __init__(
+        self,
+        content: str | None = None,
+        file: str | Path | None = None,
+    ) -> None:
+        """Initialize config."""
+        super().__init__(content, file)
+        self.incompatible = ""
 
 
 def deannotate(data: Any) -> Any:
@@ -85,10 +74,10 @@ def deannotate(data: Any) -> Any:
     return data
 
 
-@functools.lru_cache(maxsize=1)
-def load_yamllint_config() -> YamlLintConfig:
+def load_yamllint_config() -> CustomYamlLintConfig:
     """Load our default yamllint config and any customized override file."""
-    config = YamlLintConfig(content=YAMLLINT_CONFIG)
+    config = CustomYamlLintConfig(file=Path(__file__).parent / "data" / ".yamllint")
+    config.incompatible = ""
     # if we detect local yamllint config we use it but raise a warning
     # as this is likely to get out of sync with our internal config.
     for path in [
@@ -105,10 +94,65 @@ def load_yamllint_config() -> YamlLintConfig:
                 "internal yamllint config.",
                 file,
             )
-            config_override = YamlLintConfig(file=str(file))
-            config_override.extend(config)
-            config = config_override
+            custom_config = CustomYamlLintConfig(file=str(file))
+            custom_config.extend(config)
+            config = custom_config
             break
+
+    # Look for settings incompatible with our reformatting
+    checks: list[tuple[str, str | int | bool]] = [
+        (
+            "comments.min-spaces-from-content",
+            1,
+        ),
+        (
+            "comments-indentation",
+            False,
+        ),
+        (
+            "braces.min-spaces-inside",
+            0,
+        ),
+        (
+            "braces.max-spaces-inside",
+            1,
+        ),
+        (
+            "octal-values.forbid-implicit-octal",
+            True,
+        ),
+        (
+            "octal-values.forbid-explicit-octal",
+            True,
+        ),
+        # (
+        #     "key-duplicates.forbid-duplicated-merge-keys", # v1.34.0+
+        #     True,
+        # ),
+        # (
+        #   "quoted-strings.quote-type", "double",
+        # ),
+        # (
+        #   "quoted-strings.required", "only-when-needed",
+        # ),
+    ]
+    errors = []
+    for setting, expected_value in checks:
+        v = config.rules
+        for key in setting.split("."):
+            if not isinstance(v, dict):  # pragma: no cover
+                break
+            if key not in v:  # pragma: no cover
+                break
+            v = v[key]
+        if v != expected_value:
+            msg = f"{setting} must be {str(expected_value).lower()}"
+            errors.append(msg)
+    if errors:
+        nl = "\n"
+        msg = f"Found incompatible custom yamllint configuration ({file}), please either remove the file or edit it to comply with:{nl}  - {(nl + '  - ').join(errors)}.{nl}{nl}Read https://ansible.readthedocs.io/projects/lint/rules/yaml/ for more details regarding why we have these requirements. Fix mode will not be available."
+        config.incompatible = msg
+
     _logger.debug("Effective yamllint rules used: %s", config.rules)
     return config
 
@@ -201,15 +245,15 @@ def _nested_items_path(
     """
     # we have to cast each convert_to_tuples assignment or mypy complains
     # that both assignments (for dict and list) do not have the same type
-    convert_to_tuples_type = Callable[[], Iterator[tuple[str | int, Any]]]
+    # convert_to_tuples_type = Callable[[], Iterator[tuple[str | int, Any]]]
     if isinstance(data_collection, dict):
         convert_data_collection_to_tuples = cast(
-            convert_to_tuples_type,
+            "Callable[[], Iterator[tuple[str | int, Any]]]",
             functools.partial(data_collection.items),
         )
     elif isinstance(data_collection, list):
         convert_data_collection_to_tuples = cast(
-            convert_to_tuples_type,
+            "Callable[[], Iterator[tuple[str | int, Any]]]",
             functools.partial(enumerate, data_collection),
         )
     else:
@@ -253,7 +297,7 @@ def get_path_to_play(
         lc = play.lc
         if not isinstance(lc.line, int):
             msg = f"expected lc.line to be an int, got {lc.line!r}"
-            raise RuntimeError(msg)
+            raise TypeError(msg)
         if lc.line == line_index:
             return [play_index]
         if play_index > 0 and prev_play_line_index < line_index < lc.line:
@@ -305,6 +349,10 @@ def _get_path_to_task_in_playbook(
         else:
             next_play_line_index = None
 
+        # We clearly haven't found the right spot yet if a following play starts on an earlier line.
+        if next_play_line_index and lineno > next_play_line_index:
+            continue
+
         play_keys = list(play.keys())
         for tasks_keyword in PLAYBOOK_TASK_KEYWORDS:
             if not play.get(tasks_keyword):
@@ -386,7 +434,7 @@ def _get_path_to_task_in_tasks_block(
 
         if not isinstance(task.lc.line, int):
             msg = f"expected task.lc.line to be an int, got {task.lc.line!r}"
-            raise RuntimeError(msg)
+            raise TypeError(msg)
         if task.lc.line == line_index:
             return [task_index]
         if task_index > 0 and prev_task_line_index < line_index < task.lc.line:
@@ -504,7 +552,9 @@ class CustomConstructor(RoundTripConstructor):
             value_s = value_su.replace("_", "")
             if value_s[0] in "+-":
                 value_s = value_s[1:]
-            if value_s[0] == "0":
+            if value_s[0:2] == "0x":
+                ret = HexInt(ret, width=len(value_s) - 2)
+            elif value_s[0] == "0":
                 # got an octal in YAML 1.1
                 ret = OctalIntYAML11(
                     ret,
@@ -588,15 +638,33 @@ class FormattedEmitter(Emitter):
         """Select how to quote scalars if needed."""
         style = super().choose_scalar_style()
         if (
-            style == ""
+            style == ""  # noqa: PLC1901
             and self.event.value.startswith("0")
             and len(self.event.value) > 1
         ):
-            if self.event.tag == "tag:yaml.org,2002:int" and self.event.implicit[0]:
-                # ensures that "0123" string does not lose its quoting
+            # We have an as-yet unquoted token that starts with "0" (but is not itself the digit 0).
+            # It could be:
+            # - hexadecimal like "0xF1"; comes tagged as int. Should continue unquoted to continue as an int.
+            # - octal like "0666" or "0o755"; comes tagged as str. **Should** be quoted to be cross-YAML compatible.
+            # - string like "0.0.0.0" and "00-header". Should not be quoted, unless it has a quote in it.
+            if (
+                self.event.value.startswith("0x")
+                and self.event.tag == "tag:yaml.org,2002:int"
+                and self.event.implicit[0]
+            ):
+                # hexadecimal
+                self.event.tag = "tag:yaml.org,2002:str"
+                return ""
+            try:
+                int(self.event.value, 8)
+            except ValueError:
+                pass
+                # fallthrough to string
+            else:
+                # octal
                 self.event.tag = "tag:yaml.org,2002:str"
                 self.event.implicit = (True, True, True)
-            return '"'
+                return '"'
         if style != "'":
             # block scalar, double quoted, etc.
             return style
@@ -662,7 +730,7 @@ class FormattedEmitter(Emitter):
             if "#" in string:
                 # # is \uFF03 (fullwidth number sign)
                 # ﹟ is \uFE5F (small number sign)
-                string = string.replace("#", "\uFF03#\uFE5F")
+                string = string.replace("#", "\uff03#\ufe5f")
                 # this is safe even if this sequence is present
                 # because it gets reversed in post-processing
         except (ValueError, TypeError):
@@ -674,10 +742,10 @@ class FormattedEmitter(Emitter):
     def drop_octothorpe_protection(string: str) -> str:
         """Remove string protection of "#" after full-line-comment post-processing."""
         try:
-            if "\uFF03#\uFE5F" in string:
+            if "\uff03#\ufe5f" in string:
                 # # is \uFF03 (fullwidth number sign)
                 # ﹟ is \uFE5F (small number sign)
-                string = string.replace("\uFF03#\uFE5F", "#")
+                string = string.replace("\uff03#\ufe5f", "#")
         except (ValueError, TypeError):
             # probably not really a string. Whatever.
             pass
@@ -752,6 +820,16 @@ class FormattedEmitter(Emitter):
 class FormattedYAML(YAML):
     """A YAML loader/dumper that handles ansible content better by default."""
 
+    default_config = {
+        "explicit_start": True,
+        "explicit_end": False,
+        "width": 160,
+        "indent_sequences": True,
+        "preferred_quote": '"',
+        "min_spaces_inside": 0,
+        "max_spaces_inside": 1,
+    }
+
     def __init__(  # pylint: disable=too-many-arguments
         self,
         *,
@@ -760,6 +838,7 @@ class FormattedYAML(YAML):
         output: Any = None,
         plug_ins: list[str] | None = None,
         version: tuple[int, int] | None = None,
+        config: dict[str, bool | int | str] | None = None,
     ):
         """Return a configured ``ruamel.yaml.YAML`` instance.
 
@@ -829,17 +908,18 @@ class FormattedYAML(YAML):
 
         # NB: We ignore some mypy issues because ruamel.yaml typehints are not great.
 
-        config = self._defaults_from_yamllint_config()
+        if not config:
+            config = self._defaults_from_yamllint_config()
 
         # these settings are derived from yamllint config
         self.explicit_start: bool = config["explicit_start"]  # type: ignore[assignment]
         self.explicit_end: bool = config["explicit_end"]  # type: ignore[assignment]
         self.width: int = config["width"]  # type: ignore[assignment]
-        indent_sequences: bool = cast(bool, config["indent_sequences"])
-        preferred_quote: str = cast(str, config["preferred_quote"])  # either ' or "
+        indent_sequences: bool = cast("bool", config["indent_sequences"])
+        preferred_quote: str = cast("str", config["preferred_quote"])  # either ' or "
 
-        min_spaces_inside: int = cast(int, config["min_spaces_inside"])
-        max_spaces_inside: int = cast(int, config["max_spaces_inside"])
+        min_spaces_inside: int = cast("int", config["min_spaces_inside"])
+        max_spaces_inside: int = cast("int", config["max_spaces_inside"])
 
         self.default_flow_style = False
         self.compact_seq_seq = True  # type: ignore[assignment] # dash after dash
@@ -874,6 +954,7 @@ class FormattedYAML(YAML):
         # This will only preserve quotes for strings read from the file.
         # anything modified by the transform will use no quotes, preferred_quote,
         # or the quote that results in the least amount of escaping.
+        self.preserve_quotes = True
 
         # If needed, we can use this to change null representation to be explicit
         # (see https://stackoverflow.com/a/44314840/1134951)
@@ -882,15 +963,8 @@ class FormattedYAML(YAML):
     @staticmethod
     def _defaults_from_yamllint_config() -> dict[str, bool | int | str]:
         """Extract FormattedYAML-relevant settings from yamllint config if possible."""
-        config = {
-            "explicit_start": True,
-            "explicit_end": False,
-            "width": 160,
-            "indent_sequences": True,
-            "preferred_quote": '"',
-            "min_spaces_inside": 0,
-            "max_spaces_inside": 1,
-        }
+        config = FormattedYAML.default_config
+
         for rule, rule_config in load_yamllint_config().rules.items():
             if not rule_config:
                 # rule disabled
@@ -923,7 +997,7 @@ class FormattedYAML(YAML):
                 elif quote_type == "double":
                     config["preferred_quote"] = '"'
 
-        return cast(dict[str, bool | int | str], config)
+        return cast("dict[str, bool | int | str]", config)
 
     @property
     def version(self) -> tuple[int, int] | None:
@@ -939,20 +1013,20 @@ class FormattedYAML(YAML):
         return None
 
     @version.setter
-    def version(self, value: tuple[int, int] | None) -> None:
+    def version(self, val: tuple[int, int] | None) -> None:
         """Ensure that yaml version uses our default value.
 
         The yaml Reader updates this value based on the ``%YAML`` directive in files.
         So, if a file does not include the directive, it sets this to None.
         But, None effectively resets the parsing version to YAML 1.2 (ruamel's default).
         """
-        if value is not None:
-            self._yaml_version = value
+        if val is not None:
+            self._yaml_version = val
         elif hasattr(self, "_yaml_version_default"):
             self._yaml_version = self._yaml_version_default
         # We do nothing if the object did not have a previous default version defined
 
-    def load(self, stream: Path | StreamTextType) -> Any:
+    def load(self, stream: Path | Any) -> Any:
         """Load YAML content from a string while avoiding known ruamel.yaml issues."""
         if not isinstance(stream, str):
             msg = f"expected a str but got {type(stream)}"
@@ -968,7 +1042,9 @@ class FormattedYAML(YAML):
             data = self.load_all(stream=text)
         except ParserError:
             data = None
-            _logger.error("Invalid yaml, verify the file contents and try again.")
+            _logger.error(  # noqa: TRY400
+                "Invalid yaml, verify the file contents and try again.",
+            )
         if preamble_comment is not None and isinstance(
             data,
             CommentedMap | CommentedSeq,
@@ -992,6 +1068,7 @@ class FormattedYAML(YAML):
         return self._post_process_yaml(
             text,
             strip_version_directive=strip_version_directive,
+            strip_explicit_start=not self.explicit_start,
         )
 
     def _prevent_wrapping_flow_style(self, data: Any) -> None:
@@ -1019,17 +1096,17 @@ class FormattedYAML(YAML):
                 indent += self.sequence_dash_offset
             elif isinstance(parent_key, int):
                 # next level is a sequence
-                indent += cast(int, self.sequence_indent)
+                indent += cast("int", self.sequence_indent)
             elif isinstance(parent_key, str):
                 # next level is a map
-                indent += cast(int, self.map_indent)
+                indent += cast("int", self.map_indent)
 
         if isinstance(key, int) and indent == 0:
             # flow map is an item in a root-level sequence
             indent += self.sequence_dash_offset
         elif isinstance(key, int) and indent > 0:
             # flow map is in a sequence
-            indent += cast(int, self.sequence_indent)
+            indent += cast("int", self.sequence_indent)
         elif isinstance(key, str):
             # flow map is in a map
             indent += len(key + ": ")
@@ -1080,7 +1157,12 @@ class FormattedYAML(YAML):
         return text, "".join(preamble_comments) or None
 
     @staticmethod
-    def _post_process_yaml(text: str, *, strip_version_directive: bool = False) -> str:
+    def _post_process_yaml(
+        text: str,
+        *,
+        strip_version_directive: bool = False,
+        strip_explicit_start: bool = False,
+    ) -> str:
         """Handle known issues with ruamel.yaml dumping.
 
         Make sure there's only one newline at the end of the file.
@@ -1096,6 +1178,10 @@ class FormattedYAML(YAML):
         if strip_version_directive and text.startswith("%YAML"):
             text = text.split("\n", 1)[1]
 
+        # remove explicit document start
+        if strip_explicit_start and text.startswith("---"):
+            text = text.split("\n", 1)[1]
+
         text = text.rstrip("\n") + "\n"
 
         lines = text.splitlines(keepends=True)
@@ -1121,12 +1207,21 @@ class FormattedYAML(YAML):
 
                 full_line_comments.append((i, stripped))
             elif full_line_comments:
+                # match ident of previous non-blank line
+                if not lines[i - 1].lstrip():
+                    prev = lines[i - 2]
+                    space_length = len(prev) - len(prev.lstrip())
+
                 # end of full line comments so adjust to match indent of this line
                 spaces = " " * space_length
                 for index, comment in full_line_comments:
                     lines[index] = spaces + comment
                 full_line_comments.clear()
 
+            if line.rpartition(" ")[2] == "\n":
+                # drop any trailing spaces
+                lines[i] = line.rstrip() + "\n"
+
             cleaned = line.strip()
             if not cleaned.startswith("#") and cleaned.endswith("-"):
                 # got an empty list item. drop any trailing spaces.
